function ShowApplication(settings) {
    this.showButtons = [];
    this.user = settings.user || "user";
    this.password = settings.password || "password";
    this.hostname = settings.hostname || window.location.hostname;
}

ShowApplication.prototype = {
    initialize: function() {
        // Get the interfaces to control the remote video player
        IDAL.getRemoteControlInterfaces(this.hostname, this.user, this.password)
            .then(this.onIfacesAvailable.bind(this));

        // Initialize the show buttons
        var i = 1;
        do {
            var button = document.getElementById("show" + i);
            if (button) {
                this.showButtons.push(button);
                button.addEventListener("click", this.playFolder.bind(this, i))
                i++;
            }
        } while(button);

        // Initialize the stop button
        var button = document.getElementById("stop");
        if (button) {
            button.addEventListener("click", this.stopPlayback.bind(this));
            this.stopButton = button;
        }
    },

    /**
     * Play a folder, displaying an error alert in case of an error.
     * @param {Number} folder is the folder number
     */
    playFolder: function(folder) {
        if (this.ifaces) {
            this.ifaces.player.playFolder(folder)
                .catch(this.displayErrorMessage.bind(this, "Impossible de lire le dossier " + folder));
        } else {
            this.displayErrorMessage("Interfaces de communication avec le lecteur non disponibles");
        }
    },

    /**
     * Stop playback
     */
    stopPlayback: function() {
        if (this.ifaces) {
            this.ifaces.player.stop()
               .catch(this.displayErrorMessage.bind(this, "Impossible d'arrêter la lecture"));
        } else {
            this.displayErrorMessage("Interfaces de communication avec le lecteur non disponibles");
        }
    },

    /**
     * Display an error message dialog
     * @param {String} message is the error message
     */
    displayErrorMessage: function(message) {
        alert(message);
    },

    /**
     * Callback invoked when the control
     * @param {IdalControlInterfaces} ifaces The player control interfaces
     */
    onIfacesAvailable: function(ifaces) {
        this.ifaces = ifaces;

        // Get the current player state
        ifaces.player.getState()
            .then(function(state) {
                if (state == "playing" || state == "paused") {
                    return ifaces.player.getFolderNumber();
                }
                return -1;
            })
            .then(this.highlightShowButton.bind(this));

        // Add listener to get the player events
        ifaces.player.addListener(this.onPlayerEvent.bind(this));
    },

    /**
     * Player event listener, handle button state changes when the
     * player state is modified.
     * @param {*} e event having type "idal-player-event"
     */
    onPlayerEvent: function(e) {
        console.log(JSON.stringify(e));
        var detail = e.detail;
        switch (detail.type) {

            case "folder-enter":
                this.highlightShowButton(detail.folder.number);
                break;

            case "folder-leave":
                this.highlightShowButton(-1);
                break;

            case "file-start":
                this.highlightShowButton(detail.folder.number);
                break;

            case "state-change":
                if (detail.state == "stopped" || detail.state == "maintenance") {
                    this.highlightShowButton(-1);
                }
                break;

            default:
                break;
        }
    },

    /**
     * Change the state of the show buttons.
     * @param {number} folder is the folder number corresponding to the button
     */
    highlightShowButton: function(folder) {
        var buttonIndex = folder - 1;
        for (var i = 0 ; i < this.showButtons.length ; i++) {
            if (i == buttonIndex) {
                this.showButtons[i].classList.add("active");
            } else {
                this.showButtons[i].classList.remove("active");
            }
        }

        if (this.stopButton) {
            if (folder > 0) {
                this.stopButton.classList.remove("active");
            } else {
                this.stopButton.classList.add("active");
            }
        }
    }
};

